@@ -1,6 +1,6 @@
 /* _NVRM_COPYRIGHT_BEGIN_
  *
- * Copyright 2001 by NVIDIA Corporation.  All rights reserved.  All
+ * Copyright 2001-2011 by NVIDIA Corporation.  All rights reserved.  All
  * information contained herein is proprietary and confidential to NVIDIA
  * Corporation.  Any use, reproduction, or disclosure without the written
  * permission of NVIDIA Corporation is prohibited.
@@ -49,7 +49,6 @@
 #include <machine/cpu.h>
 #include <machine/resource.h>
 #include <machine/clock.h>
-#include <machine/stdarg.h>
 #include <machine/bus.h>
 #include <machine/specialreg.h>
 
@@ -105,6 +104,12 @@
 #define suser(_td) priv_check((_td), PRIV_DRIVER)
 #endif
 
+#if __FreeBSD_version >= 900041
+#include <sys/capability.h>
+#else
+#define fget(td, fd, cap, fp) fget(td, fd, fp)
+#endif
+
 #define __NV_ITHREAD() (curthread->td_pflags & TDP_ITHREAD)
 
 /*
@@ -383,8 +388,9 @@ NvS32  nv_free_agp_pages     (nv_state_t *, NvU32, void *, NvU32 *);
 void   nvidia_sysctl_init    (void);
 void   nvidia_sysctl_exit    (void);
 
-int    nvidia_sysctl_dev_model  (SYSCTL_HANDLER_ARGS);
-int    nvidia_sysctl_dev_vbios  (SYSCTL_HANDLER_ARGS);
+int    nvidia_sysctl_gpu_model  (SYSCTL_HANDLER_ARGS);
+int    nvidia_sysctl_gpu_uuid   (SYSCTL_HANDLER_ARGS);
+int    nvidia_sysctl_gpu_vbios  (SYSCTL_HANDLER_ARGS);
 int    nvidia_sysctl_bus_type   (SYSCTL_HANDLER_ARGS);
 
 int    nvidia_sysctl_registry_key     (SYSCTL_HANDLER_ARGS);
