@@ -13,6 +13,7 @@
 #define _NV_H_
 
 #include <nvtypes.h>
+#include <stdarg.h>
 
 #if !defined(NV_MIN)
 #define NV_MIN(_a,_b) ((_a) < (_b) ? (_a) : (_b))
@@ -40,7 +41,7 @@
 
 #if defined(NV_SUNOS)
 #define NV_PLATFORM_MAX_IOCTL_SIZE  255
-#elif (defined(NV_LINUX) || defined(NV_BSD) || defined(NV_USER_MAP))
+#elif (defined(NV_LINUX) || defined(NV_BSD) || defined(NV_VMWARE))
 #define NV_PLATFORM_MAX_IOCTL_SIZE  4096
 #else
 #error "The maximum ioctl() argument size is undefined!"
@@ -210,13 +211,13 @@ typedef union
 typedef struct
 {
     NvU64 address;
+    NvU64 strapped_size;
     NvU64 size;
     NvU32 offset;
     NvU32 *map;
     nv_phwreg_t map_u;
 } nv_aperture_t;
 
-
 typedef struct
 {
     char *node;
@@ -269,7 +270,6 @@ typedef struct
     void  *priv;                    /* private data */
     void  *os_state;                /* os-specific device state */
 
-    int    rmInitialized;
     int    flags;
 
     /* PCI config info */
@@ -337,6 +337,7 @@ typedef struct
 #define NV_FLAG_GVI                    0x0200
 #define NV_FLAG_GVI_INTR_EN            0x0400
 #define NV_FLAG_PERSISTENT_SW_STATE    0x0800
+#define NV_FLAG_IN_RECOVERY            0x1000
 
 #define NV_PM_APM_SUSPEND       0x0001
 #define NV_PM_APM_RESUME        0x0002
@@ -402,10 +403,17 @@ typedef struct
 #define NV_ACPI_MXMI_HANDLE_PRESENT 0x08
 #define NV_ACPI_MXMS_HANDLE_PRESENT 0x10
 
-#define NV_ACPI_METHOD_NVIF     0x01
-#define NV_ACPI_METHOD_WMMX     0x02
-#define NV_ACPI_METHOD_MXMI     0x03
-#define NV_ACPI_METHOD_MXMS     0x04
+#define NV_EVAL_ACPI_METHOD_NVIF     0x01
+#define NV_EVAL_ACPI_METHOD_WMMX     0x02
+#define NV_EVAL_ACPI_METHOD_MXMI     0x03
+#define NV_EVAL_ACPI_METHOD_MXMS     0x04
+
+#define NV_I2C_CMD_READ              1
+#define NV_I2C_CMD_WRITE             2
+#define NV_I2C_CMD_SMBUS_READ        3
+#define NV_I2C_CMD_SMBUS_WRITE       4
+#define NV_I2C_CMD_SMBUS_QUICK_WRITE 5
+#define NV_I2C_CMD_SMBUS_QUICK_READ  6
 
 /*
 ** where we hide our nv_state_t * ...
@@ -521,8 +529,8 @@ typedef struct
 void*  NV_API_CALL  nv_alloc_kernel_mapping      (nv_state_t *, NvU64, NvU64, void **);
 RM_STATUS  NV_API_CALL  nv_free_kernel_mapping   (nv_state_t *, void *, void *, NvBool);
 
-void*  NV_API_CALL  nv_alloc_user_mapping        (nv_state_t *, NvU64, NvU64, NvU32, void **);
-RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, void *, void *);
+RM_STATUS  NV_API_CALL  nv_alloc_user_mapping    (nv_state_t *, NvU64, NvU64, NvU32, NvU64 *, void **);
+RM_STATUS  NV_API_CALL  nv_free_user_mapping     (nv_state_t *, NvU64, void *);
 
 NvU64  NV_API_CALL  nv_get_kern_phys_address     (NvU64);
 NvU64  NV_API_CALL  nv_get_user_phys_address     (NvU64);
@@ -561,14 +569,7 @@ void*  NV_API_CALL  nv_get_smu_state             (void);
 RM_STATUS  NV_API_CALL  nv_lock_user_pages       (nv_state_t *, void *, NvU64, NvU64 *, void **);
 RM_STATUS  NV_API_CALL  nv_unlock_user_pages     (nv_state_t *, NvU64, NvU64 *, void *);
 RM_STATUS  NV_API_CALL  nv_acpi_rom_method       (nv_state_t *, NvU32 *, NvU32 *);
-RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, void *);
-
-#ifdef NV_USER_MAP
-#include "nv-map.h"
-#else /* NV_USER_MAP */
-#define NV_FILE_REFERENCE(file_p) ((void *) (file_p))
-#define NV_GET_VOID_FILE_PRIVATE(vfp_p) (NV_GET_FILE_PRIVATE(((struct file * ) (vfp_p))))
-#endif /* NV_USER_MAP */
+RM_STATUS  NV_API_CALL  nv_log_error             (nv_state_t *, NvU32, const char *, va_list);
 
 /*
  * ---------------------------------------------------------------------------
@@ -591,7 +592,8 @@ BOOL       NV_API_CALL  rm_isr                   (nv_stack_t *, nv_state_t *, Nv
 void       NV_API_CALL  rm_isr_bh                (nv_stack_t *, nv_state_t *);
 RM_STATUS  NV_API_CALL  rm_power_management      (nv_stack_t *, nv_state_t *, NvU32, NvU32);
 RM_STATUS  NV_API_CALL  rm_save_low_res_mode     (nv_stack_t *, nv_state_t *);
-NvU32      NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
+RM_STATUS  NV_API_CALL  rm_get_vbios_version     (nv_stack_t *, nv_state_t *, NvU32 *, NvU32 *, NvU32 *, NvU32 *, NvU32 *);
+RM_STATUS  NV_API_CALL  rm_get_gpu_uuid          (nv_stack_t *, nv_state_t *, NvU8 **, NvU32 *);
 void       NV_API_CALL  rm_free_unused_clients   (nv_stack_t *, nv_state_t *, void *);
 
 void       NV_API_CALL  rm_update_agp_config     (nv_stack_t *, nv_state_t *);
@@ -624,16 +626,12 @@ void       NV_API_CALL  rm_unregister_compatible_ioctls (nv_stack_t *);
 BOOL       NV_API_CALL  rm_is_legacy_device      (nv_stack_t *, NvU16, BOOL);
 BOOL       NV_API_CALL  rm_is_supported_device   (nv_stack_t *, nv_state_t *);
 
-RM_STATUS  NV_API_CALL  rm_i2c_read_buffer        (nv_stack_t *, nv_state_t *, void *, NvU8, NvU32, NvU8 *);
-RM_STATUS  NV_API_CALL  rm_i2c_write_buffer       (nv_stack_t *, nv_state_t *, void *, NvU8, NvU32, NvU8 *);
-RM_STATUS  NV_API_CALL  rm_i2c_smbus_write_quick  (nv_stack_t *, nv_state_t *, void *, NvU8, NvU8);
-RM_STATUS  NV_API_CALL  rm_i2c_smbus_read_buffer  (nv_stack_t *, nv_state_t *, void *, NvU8, NvU8, NvU32, NvU8 *);
-RM_STATUS  NV_API_CALL  rm_i2c_smbus_write_buffer (nv_stack_t *, nv_state_t *, void *, NvU8, NvU8, NvU32, NvU8 *);
 
 void       NV_API_CALL  rm_check_pci_config_space (nv_stack_t *, nv_state_t *nv, BOOL, BOOL, BOOL);
 
 RM_STATUS  NV_API_CALL  rm_i2c_remove_adapters    (nv_stack_t *, nv_state_t *);
 NvBool     NV_API_CALL  rm_i2c_is_smbus_capable   (nv_stack_t *, nv_state_t *, void *);
+RM_STATUS  NV_API_CALL  rm_i2c_transfer           (nv_stack_t *, nv_state_t *, void *, NvU8, NvU8, NvU8, NvU32, NvU8 *);
 
 RM_STATUS  NV_API_CALL  rm_perform_version_check  (nv_stack_t *, nv_ioctl_rm_api_version_t *);
 
@@ -645,6 +643,11 @@ RM_STATUS  NV_API_CALL  rm_resume_smu             (nv_stack_t *);
 
 void       NV_API_CALL  rm_disable_gpu_state_persistence    (nv_stack_t *sp, nv_state_t *);
 
+RM_STATUS  NV_API_CALL  rm_p2p_init_mapping       (nv_stack_t *, NvU64, NvU64 *, NvU64 *, NvU64 *, NvU64 *, NvU64, NvU64, NvU64, NvU64, void (*)(void *), void *);
+RM_STATUS  NV_API_CALL  rm_p2p_destroy_mapping    (nv_stack_t *, NvU64);
+RM_STATUS  NV_API_CALL  rm_p2p_get_pages          (nv_stack_t *, NvU64, NvU32, NvU64, NvU64, NvU64 **, NvU32 **, NvU32 **, NvU32 *, void *, void (*)(void *), void *);
+RM_STATUS  NV_API_CALL  rm_p2p_put_pages          (nv_stack_t *, NvU64, NvU32, NvU64, void *);
+
 #define rm_disable_interrupts(sp) rm_set_interrupts((sp),FALSE)
 #define rm_enable_interrupts(sp)  rm_set_interrupts((sp),TRUE)
 
