@@ -45,7 +45,8 @@ int nvidia_attach(device_t dev)
     for (i = 0; i < NV_GPU_NUM_BARS; i++) {
         if (sc->BAR_recs[i] != NULL) {
             nv->bars[i].address = rman_get_start(sc->BAR_recs[i]);
-            nv->bars[i].size = rman_get_size(sc->BAR_recs[i]);
+            nv->bars[i].strapped_size = rman_get_size(sc->BAR_recs[i]);
+            nv->bars[i].size = nv->bars[i].strapped_size;
         }
     }
 
@@ -1110,20 +1111,22 @@ RM_STATUS NV_API_CALL nv_free_kernel_mapping(
     return RM_OK;
 }
 
-void* NV_API_CALL nv_alloc_user_mapping(
+RM_STATUS NV_API_CALL nv_alloc_user_mapping(
     nv_state_t *nv,
     NvU64       address,
     NvU64       size,
     NvU32       protect,
-    void      **priv_data
+    NvU64      *user_address,
+    void      **private
 )
 {
-    return (void *)(NvUPtr)address;
+    *user_address = address;
+    return RM_OK;
 }
 
 RM_STATUS NV_API_CALL nv_free_user_mapping(
     nv_state_t *nv,
-    void       *address,
+    NvU64       user_address,
     void       *priv_data
 )
 {
@@ -1926,7 +1929,7 @@ RM_STATUS NV_API_CALL nv_log_error(
     nv_state_t *nv,
     NvU32       error_number,
     const char *format,
-    void       *ap
+    va_list    ap
 )
 {
     return RM_OK;
